pub struct DirectoryNodes { /* private fields */ }Expand description
Represents all directory nodes of a cgroup hierarchy.
Implementations
Sourceimpl DirectoryNodes
impl DirectoryNodes
pub fn new(root_cgroup: Weak<CgroupRoot>) -> Arc<DirectoryNodes>
Sourcepub fn get_node(&self, cgroup: &Arc<Cgroup>) -> Result<FsNodeHandle, Errno>
pub fn get_node(&self, cgroup: &Arc<Cgroup>) -> Result<FsNodeHandle, Errno>
Looks for the corresponding node in the filesystem, errors if not found.
Sourcepub fn get_nodes(&self, cgroups: &Vec<Arc<Cgroup>>) -> Vec<Option<FsNodeHandle>>
pub fn get_nodes(&self, cgroups: &Vec<Arc<Cgroup>>) -> Vec<Option<FsNodeHandle>>
Returns the corresponding nodes for a set of cgroups.
Sourcepub fn add_node(
&self,
cgroup: &Arc<Cgroup>,
directory: CgroupDirectoryHandle,
fs: &FileSystemHandle,
) -> FsNodeHandle
pub fn add_node( &self, cgroup: &Arc<Cgroup>, directory: CgroupDirectoryHandle, fs: &FileSystemHandle, ) -> FsNodeHandle
Creates a new FsNode for directory and stores it in nodes.
Sourcepub fn remove_node(&self, cgroup: &Arc<Cgroup>) -> Result<FsNodeHandle, Errno>
pub fn remove_node(&self, cgroup: &Arc<Cgroup>) -> Result<FsNodeHandle, Errno>
Removes an entry from nodes, errors if not found.